PubAddOptionsPatterns extension

Adds pattern-matching-related methods to PubAddOptions.

on

Methods

map<TResult extends Object?>(TResult $default(_PubAddOptions value)) → TResult

Available on PubAddOptions, provided by the PubAddOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PubAddOptions value)?) → TResult?

Available on PubAddOptions, provided by the PubAddOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PubAddOptions value)?, {required TResult orElse()}) → TResult

Available on PubAddOptions, provided by the PubAddOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool precompile)?, {required TResult orElse()}) → TResult

Available on PubAddOptions, provided by the PubAddOptionsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool precompile)) → TResult

Available on PubAddOptions, provided by the PubAddOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool precompile)?) → TResult?

Available on PubAddOptions, provided by the PubAddOptionsPatterns extension

A variant of when that fallback to returning null