PubGetOptions class abstract

Available extensions
Annotations
  • @freezed

Constructors

PubGetOptions({required GlobalPubOptions globalPubOptions, required bool offline, required bool dryRun, required bool enforceLockfile, required bool precompile})
const
factory
PubGetOptions.fromArgResults(ArgResults results)
factory

Properties

copyWith → $PubGetOptionsCopyWith<PubGetOptions>
Create a copy of PubGetOptions with the given fields replaced by the non-null parameter values.
no setterinherited
dryRun bool
no setterinherited
enforceLockfile bool
no setterinherited
globalPubOptions GlobalPubOptions
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
offline bool
no setterinherited
precompile bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PubGetOptions value)) → TResult

Available on PubGetOptions, provided by the PubGetOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PubGetOptions value)?) → TResult?

Available on PubGetOptions, provided by the PubGetOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PubGetOptions value)?, {required TResult orElse()}) → TResult

Available on PubGetOptions, provided by the PubGetOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool enforceLockfile, bool precompile)?, {required TResult orElse()}) → TResult

Available on PubGetOptions, provided by the PubGetOptionsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool enforceLockfile, bool precompile)) → TResult

Available on PubGetOptions, provided by the PubGetOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool enforceLockfile, bool precompile)?) → TResult?

Available on PubGetOptions, provided by the PubGetOptionsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited