PubPassthroughCommand class
final
- Inheritance
-
- Mixed-in types
-
Properties
-
aliases
→ List<String>
-
Alternate names for this command.
no setteroverride
-
argParser
→ ArgParser
-
The argument parser for this command.
final
-
argResults
→ ArgResults?
-
The parsed argument results for this command.
no setterinherited
-
category
→ String
-
The command's category.
no setterinherited
-
commandAliases
→ List<String>
-
final
-
commandDescription
→ String
-
final
-
commandName
→ String
-
final
-
config
→ ConfigData
-
no setterinherited
-
description
→ String
-
A description of this command, included in usage.
no setteroverride
-
globalResults
→ ArgResults?
-
The parsed global argument results.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hidden
→ bool
-
Whether or not this command should be hidden from help listings.
no setterinherited
-
invocation
→ String
-
A single-line template for how to invoke this command (e.g.
"pub get package").
no setterinherited
-
isProjectMode
→ bool
-
no setterinherited
-
logger
→ Logger
-
final
-
name
→ String
-
The name of this command.
no setteroverride
-
parent
→ Command<int>?
-
The command's parent command, if this is a subcommand.
no setterinherited
-
runner
→ CommandRunner<int>?
-
The command runner for this command.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
subcommands
→ Map<String, Command<int>>
-
An unmodifiable view of all sublevel commands of this command.
no setterinherited
-
suggestionAliases
→ List<String>
-
Alternate non-functional names for this command.
no setterinherited
-
summary
→ String
-
A short description of this command, included in
parent's
CommandRunner.usage.
no setterinherited
-
takesArguments
→ bool
-
Whether or not this command takes positional arguments in addition to
options.
no setterinherited
-
usage
→ String
-
Generates a string displaying usage information for this command.
no setterinherited
-
An optional footer for
usage.
no setterinherited
Methods
-
addSubcommand(Command<int> command)
→ void
-
Adds
Command as a subcommand of this.
inherited
-
getCacheEnv(String cacheDir)
→ Map<String, String>
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
printUsage()
→ void
-
Prints the usage information for this command.
inherited
-
resolveCacheDir(String cacheDir)
→ String
-
inherited
-
resolveProjectPath(String value)
→ String
-
inherited
-
run()
→ Future<int>
-
Runs this command.
override
-
runAfterHook({required String commandName, required GlobalOptions globalOptions})
→ Future<int>
-
Runs the shared after-hook for the given command name if it applies.
Returns the exit code from the hook, or 0 if no hook exists.
inherited
-
runBeforeHook({required String commandName, required GlobalOptions globalOptions})
→ Future<int>
-
Runs the shared before-hook for the given command name if it applies.
Returns the exit code from the hook, or 0 if no hook exists.
inherited
-
runDartProcess({required List<String> arguments, String? workingDirectory, Map<String, String>? environment})
→ Future<int>
-
inherited
-
runPostHook({required String commandName, required GlobalOptions globalOptions})
→ Future<int>
-
Runs the post-hook for the given command name if it exists.
Returns the exit code from the hook, or 0 if no hook exists.
inherited
-
runPreHook({required String commandName, required GlobalOptions globalOptions})
→ Future<int>
-
Runs the pre-hook for the given command name if it exists.
Returns the exit code from the hook, or 0 if no hook exists.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
usageException(String message)
→ Never
-
Throws a
UsageException with message.
inherited