PubRemoveOptionsPatterns extension

Adds pattern-matching-related methods to PubRemoveOptions.

on

Methods

map<TResult extends Object?>(TResult $default(_PubRemoveOptions value)) → TResult

Available on PubRemoveOptions, provided by the PubRemoveOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PubRemoveOptions value)?) → TResult?

Available on PubRemoveOptions, provided by the PubRemoveOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PubRemoveOptions value)?, {required TResult orElse()}) → TResult

Available on PubRemoveOptions, provided by the PubRemoveOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool precompile)?, {required TResult orElse()}) → TResult

Available on PubRemoveOptions, provided by the PubRemoveOptionsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool precompile)) → TResult

Available on PubRemoveOptions, provided by the PubRemoveOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool precompile)?) → TResult?

Available on PubRemoveOptions, provided by the PubRemoveOptionsPatterns extension

A variant of when that fallback to returning null