RunOptions class abstract
- Available extensions
- Annotations
-
- @unfreezed
Constructors
- RunOptions({required GlobalOptions globalOptions, required String? script})
-
factory
- RunOptions.fromArgResults(ArgResults results)
-
factory
Properties
-
copyWith
→ $RunOptionsCopyWith<
RunOptions> -
Create a copy of RunOptions
with the given fields replaced by the non-null parameter values.
no setterinherited
- globalOptions ↔ GlobalOptions
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- script ↔ String?
-
getter/setter pairinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_RunOptions value)) → TResult -
Available on RunOptions, provided by the RunOptionsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_RunOptions value)?) → TResult? -
Available on RunOptions, provided by the RunOptionsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_RunOptions value)?, {required TResult orElse()}) → TResult -
Available on RunOptions, provided by the RunOptionsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(GlobalOptions globalOptions, String? script)?, {required TResult orElse()}) → TResult -
Available on RunOptions, provided by the RunOptionsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(GlobalOptions globalOptions, String? script)) → TResult -
Available on RunOptions, provided by the RunOptionsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(GlobalOptions globalOptions, String? script)?) → TResult? -
Available on RunOptions, provided by the RunOptionsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited