ApplyOptionsPatterns extension

Adds pattern-matching-related methods to ApplyOptions.

on

Methods

map<TResult extends Object?>(TResult $default(_ApplyOptions value)) → TResult

Available on ApplyOptions, provided by the ApplyOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ApplyOptions value)?) → TResult?

Available on ApplyOptions, provided by the ApplyOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ApplyOptions value)?, {required TResult orElse()}) → TResult

Available on ApplyOptions, provided by the ApplyOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(GlobalPatchOptions globalPatchOptions, bool force)?, {required TResult orElse()}) → TResult

Available on ApplyOptions, provided by the ApplyOptionsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(GlobalPatchOptions globalPatchOptions, bool force)) → TResult

Available on ApplyOptions, provided by the ApplyOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(GlobalPatchOptions globalPatchOptions, bool force)?) → TResult?

Available on ApplyOptions, provided by the ApplyOptionsPatterns extension

A variant of when that fallback to returning null