PatchOptionsPatterns extension

Adds pattern-matching-related methods to PatchOptions.

on

Methods

map<TResult extends Object?>(TResult $default(_PatchOptions value)) → TResult

Available on PatchOptions, provided by the PatchOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PatchOptions value)?) → TResult?

Available on PatchOptions, provided by the PatchOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PatchOptions value)?, {required TResult orElse()}) → TResult

Available on PatchOptions, provided by the PatchOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(GlobalPatchOptions globalPatchOptions, bool force)?, {required TResult orElse()}) → TResult

Available on PatchOptions, provided by the PatchOptionsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(GlobalPatchOptions globalPatchOptions, bool force)) → TResult

Available on PatchOptions, provided by the PatchOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(GlobalPatchOptions globalPatchOptions, bool force)?) → TResult?

Available on PatchOptions, provided by the PatchOptionsPatterns extension

A variant of when that fallback to returning null