DpkConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

DpkConfig({@Default.new(DpkMode.global) DpkMode mode, Catalog? catalog, List<String>? workspace, @Default.new(false) bool sortPubspec, required VersionConstraint version})
const
factory
DpkConfig.fromYaml(YamlMap yaml)
factory

Properties

catalog Catalog?
no setterinherited
copyWith → $DpkConfigCopyWith<DpkConfig>
Create a copy of DpkConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mode DpkMode
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortPubspec bool
no setterinherited
version → VersionConstraint
no setterinherited
workspace List<String>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_DpkConfig value)) → TResult

Available on DpkConfig, provided by the DpkConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_DpkConfig value)?) → TResult?

Available on DpkConfig, provided by the DpkConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_DpkConfig value)?, {required TResult orElse()}) → TResult

Available on DpkConfig, provided by the DpkConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(DpkMode mode, Catalog? catalog, List<String>? workspace, bool sortPubspec, VersionConstraint version)?, {required TResult orElse()}) → TResult

Available on DpkConfig, provided by the DpkConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(DpkMode mode, Catalog? catalog, List<String>? workspace, bool sortPubspec, VersionConstraint version)) → TResult

Available on DpkConfig, provided by the DpkConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(DpkMode mode, Catalog? catalog, List<String>? workspace, bool sortPubspec, VersionConstraint version)?) → TResult?

Available on DpkConfig, provided by the DpkConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited