DpkWorkspaceEnvironment class abstract

Available extensions
Annotations
  • @freezed

Constructors

DpkWorkspaceEnvironment({required String dpkPackagePath, required String dpkPackageName, String? dpkPackageVersion})
const
factory

Properties

copyWith → $DpkWorkspaceEnvironmentCopyWith<DpkWorkspaceEnvironment>
Create a copy of DpkWorkspaceEnvironment with the given fields replaced by the non-null parameter values.
no setterinherited
dpkPackageName String
no setterinherited
dpkPackagePath String
no setterinherited
dpkPackageVersion String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_DpkWorkspaceEnvironment value)) → TResult

Available on DpkWorkspaceEnvironment, provided by the DpkWorkspaceEnvironmentPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_DpkWorkspaceEnvironment value)?) → TResult?

Available on DpkWorkspaceEnvironment, provided by the DpkWorkspaceEnvironmentPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_DpkWorkspaceEnvironment value)?, {required TResult orElse()}) → TResult

Available on DpkWorkspaceEnvironment, provided by the DpkWorkspaceEnvironmentPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String dpkPackagePath, String dpkPackageName, String? dpkPackageVersion)?, {required TResult orElse()}) → TResult

Available on DpkWorkspaceEnvironment, provided by the DpkWorkspaceEnvironmentPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(String content) String
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String dpkPackagePath, String dpkPackageName, String? dpkPackageVersion)) → TResult

Available on DpkWorkspaceEnvironment, provided by the DpkWorkspaceEnvironmentPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String dpkPackagePath, String dpkPackageName, String? dpkPackageVersion)?) → TResult?

Available on DpkWorkspaceEnvironment, provided by the DpkWorkspaceEnvironmentPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited