GlobalOptions class abstract

Available extensions
Annotations
  • @freezed

Constructors

GlobalOptions({required String? directory, required bool verbose, required bool debug})
factory
GlobalOptions.fromArgResults(ArgResults results)
factory
GlobalOptions.internal({required String? directory, required bool verbose, required bool debug})
const
factory

Properties

copyWith → $GlobalOptionsCopyWith<GlobalOptions>
Create a copy of GlobalOptions with the given fields replaced by the non-null parameter values.
no setterinherited
debug bool
no setterinherited
directory String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isVerbose bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
no setterinherited

Methods

map<TResult extends Object?>({required TResult internal(_GlobalOptions value)}) → TResult

Available on GlobalOptions, provided by the GlobalOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? internal(_GlobalOptions value)?}) → TResult?

Available on GlobalOptions, provided by the GlobalOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult internal(_GlobalOptions value)?, required TResult orElse()}) → TResult

Available on GlobalOptions, provided by the GlobalOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult internal(String? directory, bool verbose, bool debug)?, required TResult orElse()}) → TResult

Available on GlobalOptions, provided by the GlobalOptionsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult internal(String? directory, bool verbose, bool debug)}) → TResult

Available on GlobalOptions, provided by the GlobalOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? internal(String? directory, bool verbose, bool debug)?}) → TResult?

Available on GlobalOptions, provided by the GlobalOptionsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited