GlobalPubOptions class abstract

Available extensions
Annotations
  • @freezed

Constructors

GlobalPubOptions({required GlobalOptions globalOptions, required String cacheDir, required bool? color})
factory
GlobalPubOptions.fromArgResults(ArgResults results)
factory
GlobalPubOptions.internal({required GlobalOptions globalOptions, required String cacheDir, required bool? color})
const
factory

Properties

cacheDir String
no setterinherited
color bool?
no setterinherited
copyWith → $GlobalPubOptionsCopyWith<GlobalPubOptions>
Create a copy of GlobalPubOptions with the given fields replaced by the non-null parameter values.
no setterinherited
globalOptions GlobalOptions
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult internal(_GlobalPubOptions value)}) → TResult

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? internal(_GlobalPubOptions value)?}) → TResult?

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult internal(_GlobalPubOptions value)?, required TResult orElse()}) → TResult

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult internal(GlobalOptions globalOptions, String cacheDir, bool? color)?, required TResult orElse()}) → TResult

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult internal(GlobalOptions globalOptions, String cacheDir, bool? color)}) → TResult

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? internal(GlobalOptions globalOptions, String cacheDir, bool? color)?}) → TResult?

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited