GlobalPubOptionsPatterns extension

Adds pattern-matching-related methods to GlobalPubOptions.

on

Methods

map<TResult extends Object?>({required TResult internal(_GlobalPubOptions value)}) → TResult

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? internal(_GlobalPubOptions value)?}) → TResult?

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult internal(_GlobalPubOptions value)?, required TResult orElse()}) → TResult

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult internal(GlobalOptions globalOptions, String cacheDir, bool? color)?, required TResult orElse()}) → TResult

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult internal(GlobalOptions globalOptions, String cacheDir, bool? color)}) → TResult

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? internal(GlobalOptions globalOptions, String cacheDir, bool? color)?}) → TResult?

Available on GlobalPubOptions, provided by the GlobalPubOptionsPatterns extension

A variant of when that fallback to returning null