KeyEntry class

Represents a key entry extracted from the pubspec content

Constructors

KeyEntry({required String keyName, required String leadingComments, required String? inlineComment, required List<NestedKeyEntry> nestedEntries})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inlineComment String?
final
keyName String
final
leadingComments String
final
nestedEntries List<NestedKeyEntry>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited