hasComplexValue property
bool
get
hasComplexValue
Returns true if this entry has a complex value (map/list) that needs raw preservation
Implementation
bool get hasComplexValue => rawValueBlock != null;
Returns true if this entry has a complex value (map/list) that needs raw preservation
bool get hasComplexValue => rawValueBlock != null;