WorkspaceInfo class

Information about the workspace context of a directory

Constructors

WorkspaceInfo({required bool isWorkspace, Directory? workspaceRoot, required Directory currentPackage})

Properties

currentPackage Directory
The current package directory
final
hashCode int
The hash code for this object.
no setterinherited
isWorkspace bool
Whether the directory is part of a pub workspace
final
isWorkspacePackage bool
Whether this is a package within a workspace (not the root)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspaceRoot Directory?
The workspace root directory (null if not in a workspace)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited