PubUpgradeOptions class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- PubUpgradeOptions({required GlobalPubOptions globalPubOptions, required bool offline, required bool dryRun, required bool precompile, required bool tighten, required bool unlockTransitive, required bool majorVersions})
-
constfactory
- PubUpgradeOptions.fromArgResults(ArgResults results)
-
factory
Properties
-
copyWith
→ $PubUpgradeOptionsCopyWith<
PubUpgradeOptions> -
Create a copy of PubUpgradeOptions
with the given fields replaced by the non-null parameter values.
no setterinherited
- dryRun → bool
-
no setterinherited
- globalPubOptions → GlobalPubOptions
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- majorVersions → bool
-
no setterinherited
- offline → bool
-
no setterinherited
- precompile → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tighten → bool
-
no setterinherited
- unlockTransitive → bool
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_PubUpgradeOptions value)) → TResult -
Available on PubUpgradeOptions, provided by the PubUpgradeOptionsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_PubUpgradeOptions value)?) → TResult? -
Available on PubUpgradeOptions, provided by the PubUpgradeOptionsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_PubUpgradeOptions value)?, {required TResult orElse()}) → TResult -
Available on PubUpgradeOptions, provided by the PubUpgradeOptionsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool precompile, bool tighten, bool unlockTransitive, bool majorVersions)?, {required TResult orElse()}) → TResult -
Available on PubUpgradeOptions, provided by the PubUpgradeOptionsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool precompile, bool tighten, bool unlockTransitive, bool majorVersions)) → TResult -
Available on PubUpgradeOptions, provided by the PubUpgradeOptionsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(GlobalPubOptions globalPubOptions, bool offline, bool dryRun, bool precompile, bool tighten, bool unlockTransitive, bool majorVersions)?) → TResult? -
Available on PubUpgradeOptions, provided by the PubUpgradeOptionsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited