GlobalPatchOptions class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- GlobalPatchOptions({required GlobalOptions globalOptions, required String cacheDir, required String patchDir})
-
factory
- GlobalPatchOptions.fromArgResults(ArgResults results)
-
factory
- GlobalPatchOptions.internal({required GlobalOptions globalOptions, required String cacheDir, required String patchDir})
-
constfactory
Properties
- cacheDir → String
-
no setterinherited
-
copyWith
→ $GlobalPatchOptionsCopyWith<
GlobalPatchOptions> -
Create a copy of GlobalPatchOptions
with the given fields replaced by the non-null parameter values.
no setterinherited
- globalOptions → GlobalOptions
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- patchDir → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> ({required TResult internal(_GlobalPatchOptions value)}) → TResult -
Available on GlobalPatchOptions, provided by the GlobalPatchOptionsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? internal(_GlobalPatchOptions value)?}) → TResult? -
Available on GlobalPatchOptions, provided by the GlobalPatchOptionsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult internal(_GlobalPatchOptions value)?, required TResult orElse()}) → TResult -
Available on GlobalPatchOptions, provided by the GlobalPatchOptionsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult internal(GlobalOptions globalOptions, String cacheDir, String patchDir)?, required TResult orElse()}) → TResult -
Available on GlobalPatchOptions, provided by the GlobalPatchOptionsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> ({required TResult internal(GlobalOptions globalOptions, String cacheDir, String patchDir)}) → TResult -
Available on GlobalPatchOptions, provided by the GlobalPatchOptionsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? internal(GlobalOptions globalOptions, String cacheDir, String patchDir)?}) → TResult? -
Available on GlobalPatchOptions, provided by the GlobalPatchOptionsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited