NestedKeyEntry class
Represents a nested key entry (for dependency sections)
Constructors
- NestedKeyEntry({required String keyName, required String leadingComments, required String? inlineComment, String? rawValueBlock})
-
const
Properties
- hasComplexValue → bool
-
Returns true if this entry has a complex value (map/list) that needs raw preservation
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- inlineComment → String?
-
final
- keyName → String
-
final
- leadingComments → String
-
final
- rawValueBlock → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited