TerminalLogUtil class final
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getTerminalWidth(
IOSink sink) → int -
setupStreamHandlers(
{required Stream< List< stream, required String packageName, required IOSink outputSink, required int maxLineWidth, required List<int> >int> indentBytes}) → void -
wrapLineWithAnsi(
List< int> lineBytes, int maxWidth, List<int> indentBytes) → List<List< int> >
Constants
- indentLength → const int
- newlineByte → const int